@@ -21,5 +21,5 @@ class NeoStorage(BaseConfig):
     def open(self):
         from .Storage import Storage
         config = self.config
-        return Storage(**dict((k, getattr(config, k))
-                              for k in config.getSectionAttributes()))
+        return Storage(**{k: getattr(config, k)
+                          for k in config.getSectionAttributes()})
