@@ -274,9 +274,7 @@ class TransactionManager(object):
                 dump(oid), dump(ttid), dump(locking_tid))
             raise ConflictError(ZERO_TID)
         if previous_serial is None:
-            history_list = self._app.dm.getObjectHistory(oid)
-            if history_list:
-                previous_serial = history_list[0][0]
+            previous_serial = self._app.dm.getLastObjectTID(oid)
         if previous_serial is not None and previous_serial != serial:
             logging.info('Resolvable conflict on %r:%r',
                 dump(oid), dump(ttid))
@@ -301,7 +299,7 @@ class TransactionManager(object):
         if data is None:
             data_id = None
         else:
-            data_id = self._app.dm.storeData(checksum, data, compression)
+            data_id = self._app.dm.holdData(checksum, data, compression)
         self._transaction_dict[ttid].addObject(oid, data_id, value_serial)
 
     def abort(self, ttid, even_if_locked=False):
@@ -324,7 +322,7 @@ class TransactionManager(object):
             if not even_if_locked:
                 return
         else:
-            self._app.dm.unlockData([data_id
+            self._app.dm.releaseData([data_id
                 for oid, data_id, value_serial in transaction.getObjectList()
                 if data_id], True)
         # unlock any object
@@ -389,5 +387,5 @@ class TransactionManager(object):
                 if new_serial:
                     data_id = None
                 else:
-                    self._app.dm.storeData(data_id)
+                    self._app.dm.holdData(data_id)
                 transaction.addObject(oid, data_id, new_serial)
