@@ -30,6 +30,7 @@ import tempfile
 import traceback
 import threading
 import psutil
+from ConfigParser import SafeConfigParser
 
 import neo.scripts
 from neo.neoctl.neoctl import NeoCTL, NotReadyException
@@ -67,7 +68,7 @@ class NotFound(Exception):
 class PortAllocator(object):
 
     lock = SocketLock('neo.PortAllocator')
-    allocator_set = weakref.WeakKeyDictionary() # BBB: use WeakSet instead
+    allocator_set = weakref.WeakSet()
 
     def __init__(self):
         self.socket_list = []
@@ -81,7 +82,7 @@ class PortAllocator(object):
         s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         if not self.lock.locked():
             self.lock.acquire()
-        self.allocator_set[self] = None
+        self.allocator_set.add(self)
         self.socket_list.append(s)
         sock_port_set = self.sock_port_set
         while True:
@@ -109,7 +110,7 @@ class PortAllocator(object):
 
     def reset(self):
         if self.lock.locked():
-            self.allocator_set.pop(self, None)
+            self.allocator_set.discard(self)
             if not self.allocator_set:
                 self.lock.release()
             self.release()
@@ -126,7 +127,7 @@ class NEOProcess(object):
         except ImportError:
             raise NotFound, '%s not found' % (command)
         self.command = command
-        self.arg_dict = dict(('--' + k, v) for k, v in arg_dict.iteritems())
+        self.arg_dict = {'--' + k: v for k, v in arg_dict.iteritems()}
         self.with_uuid = True
         self.setUUID(uuid)
 
@@ -227,7 +228,7 @@ class NEOProcess(object):
 
     def isAlive(self):
         try:
-            return psutil.Process(self.pid).status != psutil.STATUS_ZOMBIE
+            return psutil.Process(self.pid).status() != psutil.STATUS_ZOMBIE
         except psutil.NoSuchProcess:
             return False
 
@@ -238,7 +239,7 @@ class NEOCluster(object):
                  cleanup_on_delete=False, temp_dir=None, clear_databases=True,
                  adapter=os.getenv('NEO_TESTS_ADAPTER'),
                  address_type=ADDRESS_TYPE, bind_ip=None, logger=True,
-        ):
+                 importer=None):
         if not adapter:
             adapter = 'MySQL'
         self.adapter = adapter
@@ -263,6 +264,21 @@ class NEOCluster(object):
         self.local_ip = local_ip = bind_ip or \
             IP_VERSION_FORMAT_DICT[self.address_type]
         self.setupDB(clear_databases)
+        if importer:
+            cfg = SafeConfigParser()
+            cfg.add_section("neo")
+            cfg.set("neo", "adapter", adapter)
+            cfg.set("neo", "database", self.db_template(*db_list))
+            for name, zodb in importer:
+                cfg.add_section(name)
+                for x in zodb.iteritems():
+                    cfg.set(name, *x)
+            importer_conf = os.path.join(temp_dir, 'importer.cfg')
+            with open(importer_conf, 'w') as f:
+                cfg.write(f)
+            adapter = "Importer"
+            self.db_template = str
+            db_list = importer_conf,
         self.process_dict = {}
         self.temp_dir = temp_dir
         self.port_allocator = PortAllocator()
