@@ -68,8 +68,9 @@ class StorageDBTests(NeoUnitTestBase):
         uuid = self.getStorageUUID()
         db.setUUID(uuid)
         self.assertEqual(uuid, db.getUUID())
-        db.setPartitionTable(1,
-            [(i, uuid, CellStates.UP_TO_DATE) for i in xrange(num_partitions)])
+        db.changePartitionTable(1,
+            [(i, uuid, CellStates.UP_TO_DATE) for i in xrange(num_partitions)],
+            reset=True)
 
     def checkConfigEntry(self, get_call, set_call, value):
         # generic test for all configuration entries accessors
@@ -97,9 +98,9 @@ class StorageDBTests(NeoUnitTestBase):
         uuid1, uuid2 = self.getStorageUUID(), self.getStorageUUID()
         cell1 = (0, uuid1, CellStates.OUT_OF_DATE)
         cell2 = (1, uuid1, CellStates.UP_TO_DATE)
-        db.setPartitionTable(ptid, [cell1, cell2])
+        db.changePartitionTable(ptid, [cell1, cell2], 1)
         result = db.getPartitionTable()
-        self.assertEqual(set(result), set([cell1, cell2]))
+        self.assertEqual(set(result), {cell1, cell2})
 
     def getOIDs(self, count):
         return map(self.getOID, xrange(count))
@@ -114,7 +115,7 @@ class StorageDBTests(NeoUnitTestBase):
         self._last_ttid = ttid = add64(self._last_ttid, 1)
         transaction = oid_list, 'user', 'desc', 'ext', False, ttid
         H = "0" * 20
-        object_list = [(oid, self.db.storeData(H, '', 1), None)
+        object_list = [(oid, self.db.holdData(H, '', 1), None)
                        for oid in oid_list]
         return (transaction, object_list)
 
@@ -225,15 +226,15 @@ class StorageDBTests(NeoUnitTestBase):
         # no partition table
         self.assertEqual(list(db.getPartitionTable()), [])
         # set one
-        db.setPartitionTable(ptid, [cell1])
+        db.changePartitionTable(ptid, [cell1], 1)
         result = db.getPartitionTable()
         self.assertEqual(list(result), [cell1])
         # then another
-        db.setPartitionTable(ptid, [cell2])
+        db.changePartitionTable(ptid, [cell2], 1)
         result = db.getPartitionTable()
         self.assertEqual(list(result), [cell2])
         # drop discarded cells
-        db.setPartitionTable(ptid, [cell2, cell3])
+        db.changePartitionTable(ptid, [cell2, cell3], 1)
         result = db.getPartitionTable()
         self.assertEqual(list(result), [])
 
@@ -253,7 +254,7 @@ class StorageDBTests(NeoUnitTestBase):
         # add more entries
         db.changePartitionTable(ptid, [cell2])
         result = db.getPartitionTable()
-        self.assertEqual(set(result), set([cell1, cell2]))
+        self.assertEqual(set(result), {cell1, cell2})
         # drop discarded cells
         db.changePartitionTable(ptid, [cell2, cell3])
         result = db.getPartitionTable()
@@ -527,9 +528,9 @@ class StorageDBTests(NeoUnitTestBase):
         tid4 = self.getNextTID()
         tid5 = self.getNextTID()
         oid1 = self.getOID(1)
-        foo = db.storeData("3" * 20, 'foo', 0)
-        bar = db.storeData("4" * 20, 'bar', 0)
-        db.unlockData((foo, bar))
+        foo = db.holdData("3" * 20, 'foo', 0)
+        bar = db.holdData("4" * 20, 'bar', 0)
+        db.releaseData((foo, bar))
         db.storeTransaction(
             tid1, (
                 (oid1, foo, None),
